from django.forms import NumberInput as Ni


class NumberInput(Ni):
    template_name = "web/forms/widgets/number.html"

    def __init__(self, attrs=None):
        super().__init__(attrs)
        self.attrs.update({'class': 'input'})



from django.forms import SelectDateWidget as Sdw


class SelectDateWidget(Sdw):
    def __init__(self, attrs=None, years=None, months=None, empty_label=None):
        super().__init__(attrs, years, months, empty_label)
        self.attrs.update({'class': 'select'})



from .text_input import TextInput
from .textarea import Textarea
from .checkbox_input import CheckboxInput
from .password_input import PasswordInput
from .number_input import NumberInput
from .email_input import EmailInput
from .date_input import DateInput
from .date_time_input import DateTimeInput
from .file_input import FileInput
from .hidden_input import HiddenInput
from .multiple_hidden_input import MultipleHiddenInput
from .null_boolean_input import NullBooleanSelect
from .textarea import Textarea
from .time_input import TimeInput
from .url_input import URLInput
